@@ -116,7 +116,7 @@ strings, you need to call the resolver manually:
 Tries to resolve the given service, protocol and domain name into a list
 of service records.
 
-Each C<$srv_rr> is an array reference with the following contents: 
+Each C<$srv_rr> is an array reference with the following contents:
 C<[$priority, $weight, $transport, $target]>.
 
 They will be sorted with lowest priority first, then randomly
@@ -129,8 +129,9 @@ Example:
 
 =item AnyEvent::DNS::any $domain, $cb->(@rrs)
 
-Tries to resolve the given domain and passes all resource records found to
-the callback.
+Tries to resolve the given domain and passes all resource records found
+to the callback. Note that this uses a DNS C<ANY> query, which, as of RFC
+8482, are officially deprecated.
 
 =item AnyEvent::DNS::ptr $domain, $cb->(@hostnames)
 
